Conductivity Module
====================================


``Conductivity class``
------------------------------------------------------------


.. autoclass:: HavNegpy.Conductivity
   

``HavNegpy.Conductivity fit function``
------------------------------------------------------------

.. automethod:: HavNegpy.Conductivity.jonscher_function

.. automethod:: HavNegpy.Conductivity.rbm_function


``HavNegpy.Conductivity dump methods``
------------------------------------------------------------

.. automethod:: HavNegpy.Conductivity.dump_parameters




``HavNegpy.Conductivity methods for fitting and saving the fit results``
--------------------------------------------------------------------------

.. automethod:: HavNegpy.Conductivity.create_analysis_file

.. automethod:: HavNegpy.Conductivity.select_range

.. automethod:: HavNegpy.Conductivity.fit

.. automethod:: HavNegpy.Conductivity.save_fit



